@@ -61,6 +61,15 @@ class CreateHealthCheckTemplateRequest(RpcRequest):
 
 	def set_HealthCheckPath(self, HealthCheckPath):  # String
 		self.add_query_param('HealthCheckPath', HealthCheckPath)
+	def get_Tag(self): # Array
+		return self.get_query_params().get('Tag')
+
+	def set_Tag(self, Tag):  # Array
+		for index1, value1 in enumerate(Tag):
+			if value1.get('Value') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Value', value1.get('Value'))
+			if value1.get('Key') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Key', value1.get('Key'))
 	def get_HealthCheckCodes(self): # Array
 		return self.get_query_params().get('HealthCheckCodes')
 
