@@ -54,6 +54,15 @@ class CreateListenerRequest(RpcRequest):
 
 	def set_Http2Enabled(self, Http2Enabled):  # Boolean
 		self.add_query_param('Http2Enabled', Http2Enabled)
+	def get_Tag(self): # Array
+		return self.get_query_params().get('Tag')
+
+	def set_Tag(self, Tag):  # Array
+		for index1, value1 in enumerate(Tag):
+			if value1.get('Value') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Value', value1.get('Value'))
+			if value1.get('Key') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Key', value1.get('Key'))
 	def get_DefaultActions(self): # Array
 		return self.get_query_params().get('DefaultActions')
 
