@@ -46,6 +46,15 @@ class CreateRuleRequest(RpcRequest):
 
 	def set_ListenerId(self, ListenerId):  # String
 		self.add_query_param('ListenerId', ListenerId)
+	def get_Tag(self): # Array
+		return self.get_query_params().get('Tag')
+
+	def set_Tag(self, Tag):  # Array
+		for index1, value1 in enumerate(Tag):
+			if value1.get('Value') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Value', value1.get('Value'))
+			if value1.get('Key') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Key', value1.get('Key'))
 	def get_Direction(self): # String
 		return self.get_query_params().get('Direction')
 
