@@ -47,7 +47,7 @@ class CreateServerGroupRequest(RpcRequest):
 	def set_HealthCheckConfig(self, HealthCheckConfig):  # Struct
 		if HealthCheckConfig.get('HealthCheckCodes') is not None:
 			for index1, value1 in enumerate(HealthCheckConfig.get('HealthCheckCodes')):
-				self.add_query_param('HealthCheckConfig.HealthCheckCodes' + str(index1 + 1), value1)
+				self.add_query_param('HealthCheckConfig.HealthCheckCodes.' + str(index1 + 1), value1)
 		if HealthCheckConfig.get('HealthCheckEnabled') is not None:
 			self.add_query_param('HealthCheckConfig.HealthCheckEnabled', HealthCheckConfig.get('HealthCheckEnabled'))
 		if HealthCheckConfig.get('HealthCheckTimeout') is not None:
@@ -70,7 +70,7 @@ class CreateServerGroupRequest(RpcRequest):
 			self.add_query_param('HealthCheckConfig.HealthCheckInterval', HealthCheckConfig.get('HealthCheckInterval'))
 		if HealthCheckConfig.get('HealthCheckHttpCodes') is not None:
 			for index1, value1 in enumerate(HealthCheckConfig.get('HealthCheckHttpCodes')):
-				self.add_query_param('HealthCheckConfig.HealthCheckHttpCodes' + str(index1 + 1), value1)
+				self.add_query_param('HealthCheckConfig.HealthCheckHttpCodes.' + str(index1 + 1), value1)
 		if HealthCheckConfig.get('HealthCheckHttpVersion') is not None:
 			self.add_query_param('HealthCheckConfig.HealthCheckHttpVersion', HealthCheckConfig.get('HealthCheckHttpVersion'))
 		if HealthCheckConfig.get('HealthCheckConnectPort') is not None:
@@ -90,6 +90,25 @@ class CreateServerGroupRequest(RpcRequest):
 
 	def set_Protocol(self, Protocol):  # String
 		self.add_query_param('Protocol', Protocol)
+	def get_UpstreamKeepaliveEnabled(self): # Boolean
+		return self.get_query_params().get('UpstreamKeepaliveEnabled')
+
+	def set_UpstreamKeepaliveEnabled(self, UpstreamKeepaliveEnabled):  # Boolean
+		self.add_query_param('UpstreamKeepaliveEnabled', UpstreamKeepaliveEnabled)
+	def get_ServiceName(self): # String
+		return self.get_query_params().get('ServiceName')
+
+	def set_ServiceName(self, ServiceName):  # String
+		self.add_query_param('ServiceName', ServiceName)
+	def get_Tag(self): # Array
+		return self.get_query_params().get('Tag')
+
+	def set_Tag(self, Tag):  # Array
+		for index1, value1 in enumerate(Tag):
+			if value1.get('Value') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Value', value1.get('Value'))
+			if value1.get('Key') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Key', value1.get('Key'))
 	def get_StickySessionConfig(self): # Struct
 		return self.get_query_params().get('StickySessionConfig')
 
@@ -117,3 +136,11 @@ class CreateServerGroupRequest(RpcRequest):
 
 	def set_VpcId(self, VpcId):  # String
 		self.add_query_param('VpcId', VpcId)
+	def get_UchConfig(self): # Struct
+		return self.get_query_params().get('UchConfig')
+
+	def set_UchConfig(self, UchConfig):  # Struct
+		if UchConfig.get('Type') is not None:
+			self.add_query_param('UchConfig.Type', UchConfig.get('Type'))
+		if UchConfig.get('Value') is not None:
+			self.add_query_param('UchConfig.Value', UchConfig.get('Value'))
