@@ -68,7 +68,7 @@ class UpdateListenerAttributeRequest(RpcRequest):
 				if value1.get('ForwardGroupConfig').get('ServerGroupTuples') is not None:
 					for index2, value2 in enumerate(value1.get('ForwardGroupConfig').get('ServerGroupTuples')):
 						if value2.get('ServerGroupId') is not None:
-							self.add_query_param('DefaultActions.' + str(index1 + 1) + '.ForwardGroupConfig.ServerGroupTuples' + str(index2 + 1) + '.ServerGroupId', value2.get('ServerGroupId'))
+							self.add_query_param('DefaultActions.' + str(index1 + 1) + '.ForwardGroupConfig.ServerGroupTuples.' + str(index2 + 1) + '.ServerGroupId', value2.get('ServerGroupId'))
 			if value1.get('Type') is not None:
 				self.add_query_param('DefaultActions.' + str(index1 + 1) + '.Type', value1.get('Type'))
 	def get_DryRun(self): # Boolean
@@ -92,8 +92,12 @@ class UpdateListenerAttributeRequest(RpcRequest):
 		return self.get_query_params().get('XForwardedForConfig')
 
 	def set_XForwardedForConfig(self, XForwardedForConfig):  # Struct
+		if XForwardedForConfig.get('XForwardedForClientSourceIpsTrusted') is not None:
+			self.add_query_param('XForwardedForConfig.XForwardedForClientSourceIpsTrusted', XForwardedForConfig.get('XForwardedForClientSourceIpsTrusted'))
 		if XForwardedForConfig.get('XForwardedForClientCertSubjectDNAlias') is not None:
 			self.add_query_param('XForwardedForConfig.XForwardedForClientCertSubjectDNAlias', XForwardedForConfig.get('XForwardedForClientCertSubjectDNAlias'))
+		if XForwardedForConfig.get('XForwardedForClientSourceIpsEnabled') is not None:
+			self.add_query_param('XForwardedForConfig.XForwardedForClientSourceIpsEnabled', XForwardedForConfig.get('XForwardedForClientSourceIpsEnabled'))
 		if XForwardedForConfig.get('XForwardedForClientCertIssuerDNEnabled') is not None:
 			self.add_query_param('XForwardedForConfig.XForwardedForClientCertIssuerDNEnabled', XForwardedForConfig.get('XForwardedForClientCertIssuerDNEnabled'))
 		if XForwardedForConfig.get('XForwardedForClientCertFingerprintEnabled') is not None:
